@@ -30,6 +30,10 @@ class AFPEntitiesParameters(ProcessorParameters):
     eurovoc_label: Optional[str] = Field(
         "eurovoc", description="Label name of the Eurovoc thesaurus"
     )
+    as_altText: str = Field(
+        "fingerprint",
+        description="""If defined generate the fingerprint as an alternative text of the input document.""",
+    )
 
 
 class AFPEntitiesProcessor(ProcessorBase):
@@ -42,14 +46,21 @@ class AFPEntitiesProcessor(ProcessorBase):
         for document in documents:
             with add_logging_context(docid=document.identifier):
                 if document.annotations:
-                    document.altTexts = document.altTexts or []
                     mark_whitelisted(document)
                     ann_groups = group_annotations(document, by_lexicon)
                     # 1. Compute document fingerprint
                     fingerprints = compute_fingerprint(ann_groups)
-                    document.altTexts.append(
-                        AltText(name="fingerprint", text=" ".join(fingerprints))
-                    )
+                    if params.as_altText is not None and len(params.as_altText):
+                        document.altTexts = document.altTexts or []
+                        altTexts = [
+                            alt
+                            for alt in document.altTexts
+                            if alt.name != params.as_altText
+                        ]
+                        altTexts.append(
+                            AltText(name=params.as_altText, text=" ".join(fingerprints))
+                        )
+                        document.altTexts = altTexts
                     # 2. Consolidate & links against KB and Wikidata
                     conso_anns = consolidate_and_link(ann_groups, params.kill_label)
                     document.annotations = conso_anns
@@ -214,6 +225,7 @@ def one_match(a: Annotation, matches: RangeMap):
     return perfect, match
 
 
+# noqa: W503
 def annotation_in_group(
     a: Annotation, ann_groups: Dict[str, RangeMap], gname: str = None
 ):
@@ -227,6 +239,7 @@ def annotation_in_group(
     return None
 
 
+# noqa: W503
 def validate_wiki_type(w: Annotation, gname: str):
     match = None
     if w.terms and len(w.terms) and w.terms[0].properties:
